@@ -1,25 +1,26 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: contacts.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: contacts.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.4  2000/06/17 16:38:45  denis
-New parameter was added in icq_ContactSetVis() for setting/resetting
-'Visible to User' status.
-Port's type was changed to unsigned short in icq_UserOnline callback.
-
-Revision 1.3  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.2  1999/07/23 12:28:00  denis
-Cleaned up.
-
-Revision 1.1  1999/07/18 20:11:48  bills
-added
-
+*
+* $Id: contacts.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
