@@ -1,131 +1,27 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: icqlib.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: icqlib.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.44  2000/07/24 03:10:08  bills
-added support for real nickname during TCP transactions like file and
-chat, instead of using Bill all the time (hmm, where'd I get that from? :)
-
-Revision 1.43  2000/07/09 22:05:11  bills
-removed unnecessary functions
-
-Revision 1.42  2000/07/09 18:28:07  denis
-Initial memset() in icq_Init() replaced by callback's clearance.
-
-Revision 1.41  2000/06/15 01:50:39  bills
-removed *Seq functions
-
-Revision 1.40  2000/05/10 19:06:59  denis
-UDP outgoing packet queue was implemented.
-
-Revision 1.39  2000/05/03 18:12:36  denis
-Unfinished UDP queue was commented out.
-
-Revision 1.38  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.37  2000/04/06 16:38:04  denis
-icq_*Send*Seq() functions with specified sequence number were added.
-
-Revision 1.36  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.35  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.34  1999/12/27 16:06:32  bills
-cleanups
-
-Revision 1.33  1999/10/03 21:35:55  tim
-Fixed "url" and "descr" parameters order when sending a URL via TCP.
-
-Revision 1.32  1999/09/29 16:49:43  denis
-Host/network/icq byteorder systemized.
-icq_Init() cleaned up.
-
-Revision 1.31  1999/07/18 20:15:55  bills
-changed to use new byte-order functions & contact list functions
-
-Revision 1.30  1999/07/16 12:27:06  denis
-Other global variables moved to ICQLINK structure.
-Initialization of random number generator added in icq_Init()
-Cleaned up.
-
-Revision 1.29  1999/07/12 15:13:31  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.28  1999/07/03 02:26:02  bills
-added new code to support thruSrv arg to SendMessage and SendURL
-
-Revision 1.27  1999/04/17 19:21:37  bills
-modified Send* Functions to return DWORD instead of WORD
-
-Revision 1.26  1999/04/14 14:48:18  denis
-Switched from icq_Log callback to icq_Fmt function.
-Cleanups for "strict" compiling (-ansi -pedantic)
-
-Revision 1.25  1999/04/05 13:14:57  denis
-Send messages and URLs to 'not in list' users fixed.
-
-Revision 1.24  1999/03/31 01:43:40  bills
-added TCP support to SendURL
-
-Revision 1.23  1999/03/30 22:47:44  lord
-list of countries now sorted.
-
-Revision 1.22  1999/03/28 03:18:22  bills
-enable tcp messaging in icq_SendMessage, uncommented icq_OurPort and
-icq_OurIp and fixed function names so icqlib compiles
-
-Revision 1.21  1999/03/25 22:16:43  bills
-added #include "util.h"
-
-Revision 1.20  1999/03/24 11:37:36  denis
-Underscored files with TCP stuff renamed.
-TCP stuff cleaned up
-Function names changed to corresponding names.
-icqlib.c splitted to many small files by subject.
-C++ comments changed to ANSI C comments.
-
-Revision 1.19  1999/03/22 20:51:28  bills
-added code in icq_HandleUserOnline to set/clear new struct entries in
-icq_ContactItem; added cleanup code in icq_HandleUserOffline for same
-
-Revision 1.18  1999/03/09 13:14:05  denis
-Cyrillic recoding removed from URLs
-
-Revision 1.17  1999/03/05 13:57:54  denis
-Some cosmetic changes...
-
-Revision 1.16  1998/12/08 16:00:59  denis
-Cleaned up a little before releasing
-
-Revision 1.15  1998/11/25 19:18:16  denis
-Added close icq_ProxySok in icq_Disconnect
-
-Revision 1.14  1998/11/25 09:48:49  denis
-icq_GetProxySok and icq_HandleProxyResponse methods added
-Connection terminated support added
-
-Revision 1.13  1998/11/19 12:22:48  denis
-SOCKS support cleaned a little
-icq_RecvUrl renamed to icq_RecvURL
-icq_ProxyAuth added for Username/Password Authentication
-URL/Description order inverted
-icq_Quit splitted to icq_Logout and icq_Disconnect
-icq_ProxyName and icq_ProxyPass range checking added
-
-Revision 1.12  1998/11/18 16:21:29  denis
-Fixed SOCKS5 proxy support
-
- */
+*
+* $Id: icqlib.c,v 1.2 2001/06/02 07:09:37 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
 
 #include "icqlib.h"
 
@@ -173,9 +69,9 @@ DWORD icq_SendMessage(ICQLINK *link, DWORD uin, const char *text, BYTE thruSrv)
     if(pcontact)
     {
       if(pcontact->tcp_flag == 0x04)
-        return icq_TCPSendMessage(link, uin, text);
+	return icq_TCPSendMessage(link, uin, text);
       else
-        return icq_UDPSendMessage(link, uin, text);
+	return icq_UDPSendMessage(link, uin, text);
     }
     else
     {
@@ -197,9 +93,9 @@ DWORD icq_SendURL(ICQLINK *link, DWORD uin, const char *url, const char *descr,
     if(pcontact)
     {
       if(pcontact->tcp_flag == 0x04)
-        return icq_TCPSendURL(link, uin, descr, url);
+	return icq_TCPSendURL(link, uin, descr, url);
       else
-        return icq_UDPSendURL(link, uin, url, descr);
+	return icq_UDPSendURL(link, uin, url, descr);
     }
     else
     {
@@ -221,9 +117,9 @@ DWORD icq_SendContact(ICQLINK *link, DWORD uin, const icqcontactmsg *contact, BY
     if(pcontact)
     {
       if(pcontact->tcp_flag == 0x04)
-        return icq_TCPSendContact(link, uin, contact);
+	return icq_TCPSendContact(link, uin, contact);
       else
-        return icq_UDPSendContact(link, uin, contact);
+	return icq_UDPSendContact(link, uin, contact);
     }
     else
     {
@@ -381,8 +277,8 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
       host_struct = gethostbyname(link->icq_ProxyHost);
       if(host_struct == 0L)
       {
-        icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Can't find hostname: %s\n", link->icq_ProxyHost);
-        return -1;
+	icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Can't find hostname: %s\n", link->icq_ProxyHost);
+	return -1;
       }
       prsin.sin_addr = *((struct in_addr*)host_struct->h_addr);
     }
@@ -419,13 +315,13 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
     {
       if(res != 2 || buf[0] != 5 || buf[1] != 2) /* username/password authentication*/
       {
-        icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authentication method incorrect\n");
+	icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authentication method incorrect\n");
 #ifdef _WIN32
-        closesocket(link->icq_ProxySok);
+	closesocket(link->icq_ProxySok);
 #else
-        close(link->icq_ProxySok);
+	close(link->icq_ProxySok);
 #endif
-        return -1;
+	return -1;
       }
       buf[0] = 1; /* version of subnegotiation */
       buf[1] = strlen(link->icq_ProxyName);
@@ -441,26 +337,26 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
 #endif
       if(res != 2 || buf[0] != 1 || buf[1] != 0)
       {
-        icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authorization failure\n");
+	icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authorization failure\n");
 #ifdef _WIN32
-        closesocket(link->icq_ProxySok);
+	closesocket(link->icq_ProxySok);
 #else
-        close(link->icq_ProxySok);
+	close(link->icq_ProxySok);
 #endif
-        return -1;
+	return -1;
       }
     }
     else
     {
       if(res != 2 || buf[0] != 5 || buf[1] != 0) /* no authentication required */
       {
-        icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authentication method incorrect\n");
+	icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Authentication method incorrect\n");
 #ifdef _WIN32
-        closesocket(link->icq_ProxySok);
+	closesocket(link->icq_ProxySok);
 #else
-        close(link->icq_ProxySok);
+	close(link->icq_ProxySok);
 #endif
-        return -1;
+	return -1;
       }
     }
     buf[0] = 5; /* protocol version */
@@ -484,33 +380,33 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
     {
       switch(buf[1])
       {
-        case 1:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] General SOCKS server failure\n");
-          break;
-        case 2:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Connection not allowed by ruleset\n");
-          break;
-        case 3:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Network unreachable\n");
-          break;
-        case 4:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Host unreachable\n");
-          break;
-        case 5:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Connection refused\n");
-          break;
-        case 6:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] TTL expired\n");
-          break;
-        case 7:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Command not supported\n");
-          break;
-        case 8:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Address type not supported\n");
-          break;
-        default:
-          icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Unknown SOCKS server failure\n");
-          break;
+	case 1:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] General SOCKS server failure\n");
+	  break;
+	case 2:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Connection not allowed by ruleset\n");
+	  break;
+	case 3:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Network unreachable\n");
+	  break;
+	case 4:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Host unreachable\n");
+	  break;
+	case 5:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Connection refused\n");
+	  break;
+	case 6:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] TTL expired\n");
+	  break;
+	case 7:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Command not supported\n");
+	  break;
+	case 8:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Address type not supported\n");
+	  break;
+	default:
+	  icq_FmtLog(link, ICQ_LOG_FATAL, "[SOCKS] Unknown SOCKS server failure\n");
+	  break;
       }
 #ifdef _WIN32
       closesocket(link->icq_ProxySok);
@@ -528,18 +424,18 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
       host_struct = gethostbyname(hostname);
       if(host_struct == 0L)
       {
-        icq_FmtLog(link, ICQ_LOG_FATAL, "Can't find hostname: %s\n", hostname);
-        if(link->icq_UseProxy)
-        {
+	icq_FmtLog(link, ICQ_LOG_FATAL, "Can't find hostname: %s\n", hostname);
+	if(link->icq_UseProxy)
+	{
 #ifdef _WIN32
-          closesocket(link->icq_ProxySok);
+	  closesocket(link->icq_ProxySok);
 #else
-          close(link->icq_ProxySok);
+	  close(link->icq_ProxySok);
 #endif
-        }
-        return -1;
+	}
+	return -1;
       } else {
-        gothost = 1;
+	gothost = 1;
       }
     }
     sin.sin_addr = *((struct in_addr *)host_struct->h_addr);
@@ -572,8 +468,15 @@ int icq_Connect(ICQLINK *link, const char *hostname, int port)
   }
   length = sizeof(sin) ;
   getsockname(link->icq_UDPSok, (struct sockaddr*)&sin, &length);
+
   link->icq_OurIP = ntohl(sin.sin_addr.s_addr);
   link->icq_OurPort = ntohs(sin.sin_port);
+
+/*
+  link->icq_OurIP = 0;
+  link->icq_OurPort = 0;
+*/
+
   return link->icq_UDPSok;
 }
 
@@ -625,8 +528,8 @@ void icq_InitNewUser(const char *hostname, DWORD port)
       s = icq_UDPSockRead(icq_UDPSok, &pak.head, sizeof(pak));
       if(icqtohs(pak.head.cmd) == SRV_NEW_UIN)
       {
-        icq_Uin = icqtohl(&pak.data[2]);
-        return;
+	icq_Uin = icqtohl(&pak.data[2]);
+	return;
       }
     }
   }
