@@ -1,114 +1,26 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcp.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: tcp.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.36  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.35  2000/06/15 01:52:16  bills
-added Cancel and Refuse functions for chat and file reqs, changed packet
-sending code to use new icq_TCPLinkSendSeq function to elimitane duplicate
-code, removed *Seq functions, renamed chat req functions
-
-Revision 1.34  2000/05/04 15:57:20  bills
-Reworked file transfer notification, small bugfixes, and cleanups.
-
-Revision 1.33  2000/04/10 18:11:45  denis
-ANSI cleanups.
-
-Revision 1.32  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.31  2000/04/06 16:38:04  denis
-icq_*Send*Seq() functions with specified sequence number were added.
-
-Revision 1.30  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.29  2000/02/15 04:02:41  bills
-warning cleanup
-
-Revision 1.28  2000/02/15 03:58:20  bills
-use new icq_ChatRusConv_n function in icq_TCPSendChatData,
-new icq_TCPSendChatData_n function
-
-Revision 1.27  2000/02/07 02:40:23  bills
-new code for SOCKS connections, more cyrillic translations
-
-Revision 1.26  2000/01/20 19:59:15  bills
-first implementation of sending file requests
-
-Revision 1.25  2000/01/16 21:28:24  bills
-renamed icq_TCPAcceptFileReq to icq_AcceptFileRequest, moved file request
-functions to new file session code
-
-Revision 1.24  2000/01/16 03:59:10  bills
-reworked list code so list_nodes don't need to be inside item structures,
-removed strlist code and replaced with generic list calls
-
-Revision 1.23  1999/12/27 16:10:04  bills
-fixed buy in icq_TCPAcceptFileReq, added icq_TCPFileSetSpeed
-
-Revision 1.22  1999/12/21 00:29:59  bills
-moved _process_packet logic into tcplink::icq_TCPLinkProcessReceived,
-removed unnecessary icq_TCPSendFile??Packet functions
-
-Revision 1.21  1999/12/14 03:31:48  bills
-fixed double delete bug in _handle_ready_sockets, added code to implement
-connect timeout
-
-Revision 1.20  1999/11/30 09:44:31  bills
-added file session logic
-
-Revision 1.19  1999/09/29 20:07:12  bills
-cleanups, moved connect logic from _handle_ready_sockets to
-icq_TCPLinkOnConnect, tcp_link->icq_TCPLink
-
-Revision 1.18  1999/09/29 17:08:48  denis
-Cleanups.
-
-Revision 1.17  1999/07/18 20:19:56  bills
-added better log messages
-
-Revision 1.16  1999/07/16 15:45:56  denis
-Cleaned up.
-
-Revision 1.15  1999/07/16 12:14:13  denis
-tcp_packet* functions renamed to icq_Packet*
-Cleaned up.
-
-Revision 1.14  1999/07/12 15:13:34  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.13  1999/07/03 06:33:49  lord
-. byte order conversion macros added
-. some compilation warnings removed
-
-Revision 1.12  1999/06/30 13:52:22  bills
-implemented non-blocking connects
-
-Revision 1.11  1999/05/03 21:41:26  bills
-initial file xfer support added- untested
-
-Revision 1.10  1999/04/29 09:35:41  denis
-Cleanups, warning removed
-
-Revision 1.9  1999/04/17 19:30:50  bills
-_major_ restructuring.  all tcp sockets (including listening sockets) are
-kept in global linked list, icq_TCPLinks. accept and listen functions
-moved to tcplink.c.  changed return values of Send* functions to DWORD.
-
-Revision 1.8  1999/04/14 14:57:05  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-Parameter port added to function icq_TCPCreateListeningSocket()
-
+*
+* $Id: tcp.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 /*
@@ -210,9 +122,9 @@ int _generate_fds(void *p, va_list data)
     if(plink->mode & TCP_LINK_MODE_CONNECTING)
     {
       if(plink->mode & (TCP_LINK_SOCKS_AUTHORIZATION | TCP_LINK_SOCKS_NOAUTHSTATUS | TCP_LINK_SOCKS_AUTHSTATUS | TCP_LINK_SOCKS_CONNSTATUS))
-        FD_SET(socket, &icqlink->TCP_readfds);
+	FD_SET(socket, &icqlink->TCP_readfds);
       else
-        FD_SET(socket, &icqlink->TCP_writefds);
+	FD_SET(socket, &icqlink->TCP_writefds);
     }
 
     if(socket+1>icqlink->TCP_maxfd)
@@ -260,7 +172,7 @@ int _handle_ready_sockets(void *p, va_list data)
       /* close the link if there was a receive error or if *
        * the remote end has closed the connection */
       if (result < 1) 
-        icq_TCPLinkClose(plink);
+	icq_TCPLinkClose(plink);
 
     }
   }
