@@ -1,38 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcpchathandle.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: tcpchathandle.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.8  2000/07/24 03:10:08  bills
-added support for real nickname during TCP transactions like file and
-chat, instead of using Bill all the time (hmm, where'd I get that from? :)
-
-Revision 1.7  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.6  2000/05/04 15:57:20  bills
-Reworked file transfer notification, small bugfixes, and cleanups.
-
-Revision 1.5  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.4  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.3  2000/02/07 02:54:45  bills
-warning cleanups.
-
-Revision 1.2  2000/02/07 02:43:37  bills
-new code for special chat functions (background, fonts, etc)
-
-Revision 1.1  1999/09/29 19:47:21  bills
-reworked chat/file handling.  fixed chat. (it's been broke since I put
-non-blocking connects in)
-
+*
+* $Id: tcpchathandle.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <time.h>
@@ -156,7 +143,7 @@ void icq_TCPChatUpdateColors(icq_TCPLink *plink, DWORD foreground, DWORD backgro
   *((DWORD *)&buffer[6]) = background;
   if(plink->icqlink->icq_RequestNotify)
     (*plink->icqlink->icq_RequestNotify)(plink->icqlink, plink->id, ICQ_NOTIFY_CHATDATA,
-                                         sizeof(buffer), buffer);
+					 sizeof(buffer), buffer);
 }
 
 void icq_TCPProcessChatPacket(icq_Packet *p, icq_TCPLink *plink)
@@ -219,7 +206,7 @@ void icq_TCPProcessChatPacket(icq_Packet *p, icq_TCPLink *plink)
       icq_TCPChatUpdateColors(plink, fg, bg);
 
       presponse=icq_TCPCreateChatInfo2Packet(plink, plink->icqlink->icq_Nick,
-        0x00ffffff, 0x00000000);
+	0x00ffffff, 0x00000000);
       icq_PacketSend(presponse, plink->socket);
       icq_PacketDelete(presponse);
       icq_ChatSessionSetStatus(pchat, CHAT_STATUS_WAIT_FONT);
@@ -236,30 +223,30 @@ void icq_TCPProcessChatPacket(icq_Packet *p, icq_TCPLink *plink)
       fontsize = 0;
       if((code = icq_PacketRead32(p)) == 0x00070004)
       {
-        icq_PacketRead32(p);
-        ip1 = icq_PacketRead32(p);
-        ip2 = icq_PacketRead32(p);
-        icq_PacketRead8(p);
-        port1 = icq_PacketRead16(p);
-        fontsize = icq_PacketRead32(p);
-        fontstyle = icq_PacketRead32(p);
-        font = icq_PacketReadString(p);
-        encoding = icq_PacketRead16(p);
+	icq_PacketRead32(p);
+	ip1 = icq_PacketRead32(p);
+	ip2 = icq_PacketRead32(p);
+	icq_PacketRead8(p);
+	port1 = icq_PacketRead16(p);
+	fontsize = icq_PacketRead32(p);
+	fontstyle = icq_PacketRead32(p);
+	font = icq_PacketReadString(p);
+	encoding = icq_PacketRead16(p);
       }
       else if(code == 0x00000006)
       {
-        icq_PacketRead32(p);
-        ip1 = icq_PacketRead32(p);
-        ip2 = icq_PacketRead32(p);
-        port1 = icq_PacketRead16(p);
-        icq_PacketRead8(p);
-        fontsize = icq_PacketRead32(p);
-        fontstyle = icq_PacketRead32(p);
-        font = icq_PacketReadString(p);
-        encoding = icq_PacketRead16(p);
+	icq_PacketRead32(p);
+	ip1 = icq_PacketRead32(p);
+	ip2 = icq_PacketRead32(p);
+	port1 = icq_PacketRead16(p);
+	icq_PacketRead8(p);
+	fontsize = icq_PacketRead32(p);
+	fontstyle = icq_PacketRead32(p);
+	font = icq_PacketReadString(p);
+	encoding = icq_PacketRead16(p);
       }
       if(font)
-        icq_TCPChatUpdateFont(plink, font, encoding, fontstyle, fontsize);
+	icq_TCPChatUpdateFont(plink, font, encoding, fontstyle, fontsize);
       presponse=icq_TCPCreateChatFontInfoPacket(plink);
       icq_PacketSend(presponse, plink->socket);
       icq_PacketDelete(presponse);
