@@ -1,81 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: tcphandle.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: tcphandle.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.12  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.11  2000/06/25 16:36:16  denis
-'\n' was added at the end of log messages.
-
-Revision 1.10  2000/05/04 15:57:20  bills
-Reworked file transfer notification, small bugfixes, and cleanups.
-
-Revision 1.9  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.8  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.7  2000/01/20 20:06:00  bills
-removed debugging printfs
-
-Revision 1.6  2000/01/20 19:59:15  bills
-first implementation of sending file requests
-
-Revision 1.5  1999/11/30 09:51:42  bills
-more file xfer logic added
-
-Revision 1.4  1999/11/11 15:10:30  guruz
-- Added Base for Webpager Messages. Please type "make fixme"
-- Removed Segfault when kicq is started the first time
-
-Revision 1.3  1999/10/01 02:28:51  bills
-icq_TCPProcessHello returns something now :)
-
-Revision 1.2  1999/10/01 00:49:20  lord
-some compilation problems are fixed.
-
-Revision 1.1  1999/09/29 19:47:21  bills
-reworked chat/file handling.  fixed chat. (it's been broke since I put
-non-blocking connects in)
-
-Revision 1.15  1999/07/16 15:45:59  denis
-Cleaned up.
-
-Revision 1.14  1999/07/16 12:10:10  denis
-tcp_packet* functions renamed to icq_Packet*
-Cleaned up.
-
-Revision 1.13  1999/07/12 15:13:41  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.12  1999/06/30 13:51:25  bills
-cleanups
-
-Revision 1.11  1999/05/03 21:41:30  bills
-initial file xfer support added- untested
-
-Revision 1.10  1999/04/29 09:36:06  denis
-Cleanups, warning removed
-
-Revision 1.9  1999/04/17 19:40:33  bills
-reworked code to use icq_TCPLinks instead of icq_ContactItem entries.
-modified ProcessChatPacket to negotiate both sending and receiving chat
-requests properly.
-
-Revision 1.8  1999/04/14 15:12:02  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-icq_ContactItem parameter added to function icq_TCPOnMessageReceived()
-Segfault fixed on spoofed messages.
-
+*
+* $Id: tcphandle.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <time.h>
@@ -180,53 +124,53 @@ void icq_TCPProcessPacket(icq_Packet *p, icq_TCPLink *plink)
     case ICQ_TCP_MESSAGE:
       switch(type)
       {
-        case ICQ_TCP_MSG_MSG:
-        case ICQ_TCP_MSG_MSG_MASS:
-          icq_TCPOnMessageReceived(plink->icqlink, uin, message, p->id, plink);
-          break;
+	case ICQ_TCP_MSG_MSG:
+	case ICQ_TCP_MSG_MSG_MASS:
+	  icq_TCPOnMessageReceived(plink->icqlink, uin, message, p->id, plink);
+	  break;
 
-        case ICQ_TCP_MSG_URL:
-        case ICQ_TCP_MSG_URL_MASS:
-          icq_TCPOnURLReceived(plink->icqlink, uin, message, p->id);
-          break;
+	case ICQ_TCP_MSG_URL:
+	case ICQ_TCP_MSG_URL_MASS:
+	  icq_TCPOnURLReceived(plink->icqlink, uin, message, p->id);
+	  break;
 
-        case ICQ_TCP_MSG_CONTACT:
-          icq_TCPOnContactReceived(plink->icqlink, uin, message, p->id, plink);
-          break;
+	case ICQ_TCP_MSG_CONTACT:
+	  icq_TCPOnContactReceived(plink->icqlink, uin, message, p->id, plink);
+	  break;
 
-        case ICQ_TCP_MSG_CHAT:
-          icq_TCPOnChatReqReceived(plink->icqlink, uin, message, p->id);
-          break;
+	case ICQ_TCP_MSG_CHAT:
+	  icq_TCPOnChatReqReceived(plink->icqlink, uin, message, p->id);
+	  break;
 
-        case ICQ_TCP_MSG_FILE:
-          icq_TCPOnFileReqReceived(plink->icqlink, uin, message, filename, filesize, p->id);
-          break;
+	case ICQ_TCP_MSG_FILE:
+	  icq_TCPOnFileReqReceived(plink->icqlink, uin, message, filename, filesize, p->id);
+	  break;
 
-        default:
-          icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, "unknown message type %d!\n", type);
-          break;
+	default:
+	  icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, "unknown message type %d!\n", type);
+	  break;
       }
       break;
 
     case ICQ_TCP_ACK:
       switch(type) {
-        case ICQ_TCP_MSG_CHAT:
-          icq_HandleChatAck(plink, p, port);
-          break;
+	case ICQ_TCP_MSG_CHAT:
+	  icq_HandleChatAck(plink, p, port);
+	  break;
 
-        case ICQ_TCP_MSG_FILE:
-          icq_HandleFileAck(plink, p, port);
-          break;
+	case ICQ_TCP_MSG_FILE:
+	  icq_HandleFileAck(plink, p, port);
+	  break;
 
-        case ICQ_TCP_MSG_MSG:
-        case ICQ_TCP_MSG_URL:
-          if(plink->icqlink->icq_RequestNotify) {
-            icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE, "received ack %d\n", p->id);
-            (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_ACK, status,
-                                               (void *)message);
-            (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SUCCESS, 0, 0);
-          }
-          break;
+	case ICQ_TCP_MSG_MSG:
+	case ICQ_TCP_MSG_URL:
+	  if(plink->icqlink->icq_RequestNotify) {
+	    icq_FmtLog(plink->icqlink, ICQ_LOG_MESSAGE, "received ack %d\n", p->id);
+	    (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_ACK, status,
+					       (void *)message);
+	    (*plink->icqlink->icq_RequestNotify)(plink->icqlink, p->id, ICQ_NOTIFY_SUCCESS, 0, 0);
+	  }
+	  break;
       }        
       break;
 
@@ -236,7 +180,7 @@ void icq_TCPProcessPacket(icq_Packet *p, icq_TCPLink *plink)
 
     default:
       icq_FmtLog(plink->icqlink, ICQ_LOG_WARNING, 
-                          "unknown packet command %d!\n", command);
+			  "unknown packet command %d!\n", command);
   }
 }
 
@@ -305,7 +249,7 @@ void icq_TCPOnMessageReceived(ICQLINK *link, DWORD uin, const char *message, DWO
   char *data;
 #ifdef TCP_PACKET_TRACE
   printf("tcp message packet received from %lu { sequence=%x }\n",
-         uin, (int)id);
+	 uin, (int)id);
 #endif
 
   if(link->icq_RecvMessage)
@@ -327,7 +271,7 @@ void icq_TCPOnMessageReceived(ICQLINK *link, DWORD uin, const char *message, DWO
     if(plink != preallink)
     {
 /*      if(icq_SpoofedMessage)
-        (*icq_SpoofedMessage(uin, ...));*/
+	(*icq_SpoofedMessage(uin, ...));*/
     }
 
     if(plink)
@@ -378,12 +322,12 @@ void icq_TCPOnContactReceived(ICQLINK *link, DWORD uin, const char *message, DWO
       tmp++;
 
       if(firstcontact) {
-        contacts = ctitem;
-        citem = ctitem;
-        firstcontact = 0;
+	contacts = ctitem;
+	citem = ctitem;
+	firstcontact = 0;
       } else {
-          citem->next = ctitem;
-          citem = ctitem;
+	  citem->next = ctitem;
+	  citem = ctitem;
       }
     }
 
@@ -393,7 +337,7 @@ void icq_TCPOnContactReceived(ICQLINK *link, DWORD uin, const char *message, DWO
     if(plink != preallink)
     {
 /*      if(icq_SpoofedMessage)
-        (*icq_SpoofedMessage(uin, ...));*/
+	(*icq_SpoofedMessage(uin, ...));*/
     }
 
     if(plink)
