@@ -1,98 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: udp.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: udp.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.23  2000/07/09 22:19:35  bills
-added new *Close functions, use *Close functions instead of *Delete
-where correct, and misc cleanup
-
-Revision 1.22  2000/07/09 18:25:44  denis
-icq_UpdateNewUserInfo() now returns seq1 instead of seq2 since it
-isn't META function.
-
-Revision 1.21  2000/06/25 16:43:19  denis
-icq_SendMetaInfoReq() was added.
-All icq_*Meta*() functions now returns sequence number 2 because their
-replies from the server are synced with it.
-
-Revision 1.20  2000/06/15 01:50:39  bills
-removed *Seq functions
-
-Revision 1.19  2000/05/10 19:06:59  denis
-UDP outgoing packet queue was implemented.
-
-Revision 1.18  2000/05/03 18:34:43  denis
-icq_UpdateNewUserInfo() was added.
-All icq_UpdateMetaInfo*() now return their sequence number.
-
-Revision 1.17  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.16  2000/04/06 19:03:07  denis
-return sequence number
-
-Revision 1.15  2000/04/06 16:36:18  denis
-So called "Online List problem" bug with Long Contact List was fixed.
-icq_*Send*Seq() functions with specified sequence number were added.
-
-Revision 1.14  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.13  1999/12/27 11:12:35  denis
-icq_UpdateMetaInfoSecurity() added for setting "My authorization is
-required", "Web Aware" and "IP Publishing".
-
-Revision 1.12  1999/10/14 11:43:28  denis
-icq_UpdateMetaInfo* functions added.
-
-Revision 1.11  1999/10/07 18:36:27  denis
-proxy.h file removed.
-
-Revision 1.10  1999/10/04 13:36:17  denis
-Cleanups.
-
-Revision 1.9  1999/09/29 20:15:30  bills
-tcp port wasn't being sent properly in login packet
-
-Revision 1.8  1999/09/29 17:13:45  denis
-Webaware functions enabled without success even with UDP v5 - need more
-investigations.
-
-Revision 1.7  1999/07/18 20:22:16  bills
-changed to use new byte-order functions & contact list functions
-
-Revision 1.6  1999/07/16 15:46:00  denis
-Cleaned up.
-
-Revision 1.5  1999/07/16 12:40:53  denis
-ICQ UDP v5 implemented.
-Encription for ICQ UDP v5 implemented.
-icq_Packet* unified interface for UDP packets implemented.
-Multipacket support of ICQ UDP v5 support added.
-
-Revision 1.4  1999/07/12 15:13:43  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.3  1999/04/29 09:40:52  denis
-Unsuccessful attempt to implement web presence (webaware) feature
-
-Revision 1.2  1999/04/14 15:04:13  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-Switched from icq_Log callback to icq_Fmt function.
-
-Revision 1.1  1999/03/24 11:37:38  denis
-Underscored files with TCP stuff renamed.
-TCP stuff cleaned up
-Function names changed to corresponding names.
-icqlib.c splitted to many small files by subject.
-C++ comments changed to ANSI C comments.
-
+*
+* $Id: udp.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #ifndef _WIN32
@@ -303,7 +230,7 @@ void icq_HandleTimeout(ICQLINK *link)
     {
       icq_Disconnect(link);
       if(link->icq_Disconnected)
-        link->icq_Disconnected(link);
+	link->icq_Disconnected(link);
       return;
     }
     pack = icq_UDPQueueGet(link);
@@ -658,7 +585,7 @@ WORD icq_SendExtInfoReq(ICQLINK *link, DWORD uin) /* V5 */
 Initializes a server search for the information specified
 ***************************************************************/
 void icq_SendSearchReq(ICQLINK *link, const char *email, const char *nick, const char *first,
-                       const char *last) /* V5 */
+		       const char *last) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_SEARCH_USER);
   char nnick[512];
@@ -717,7 +644,7 @@ void icq_RegNewUser(ICQLINK *link, const char *pass) /* V5 */
 }
 
 WORD icq_UpdateUserInfo(ICQLINK *link, const char *nick, const char *first, const char *last,
-                        const char *email) /* V5 */
+			const char *email) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_UPDATE_INFO);
   icq_PacketAppendString(p, nick);
@@ -740,10 +667,10 @@ WORD icq_UpdateAuthInfo(ICQLINK *link, DWORD auth) /* V5 */
 }
 
 WORD icq_UpdateMetaInfoSet(ICQLINK *link, const char *nick, const char *first, const char *last,
-                           const char *email, const char *email2, const char *email3,
-                           const char *city, const char *state, const char *phone, const char *fax,
-                           const char *street, const char *cellular, unsigned long zip,
-                           unsigned short cnt_code, unsigned char cnt_stat, unsigned char emailhide)
+			   const char *email, const char *email2, const char *email3,
+			   const char *city, const char *state, const char *phone, const char *fax,
+			   const char *street, const char *cellular, unsigned long zip,
+			   unsigned short cnt_code, unsigned char cnt_stat, unsigned char emailhide)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
   icq_PacketAppend16(p, META_CMD_SET_INFO);
@@ -769,8 +696,8 @@ WORD icq_UpdateMetaInfoSet(ICQLINK *link, const char *nick, const char *first, c
 }
 
 WORD icq_UpdateMetaInfoHomepage(ICQLINK *link, unsigned char age, const char *homepage,
-                                unsigned char year, unsigned char month, unsigned char day,
-                                unsigned char lang1, unsigned char lang2,
+				unsigned char year, unsigned char month, unsigned char day,
+				unsigned char lang1, unsigned char lang2,
 				unsigned char lang3, unsigned char gender)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
@@ -804,7 +731,7 @@ WORD icq_UpdateMetaInfoAbout(ICQLINK *link, const char *about)
 }
 
 WORD icq_UpdateMetaInfoSecurity(ICQLINK *link, unsigned char reqauth, unsigned char webpresence,
-                                unsigned char pubip)
+				unsigned char pubip)
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_META_USER);
   icq_PacketAppend16(p, META_CMD_SET_SECURE);
@@ -817,7 +744,7 @@ WORD icq_UpdateMetaInfoSecurity(ICQLINK *link, unsigned char reqauth, unsigned c
 }
 
 WORD icq_UpdateNewUserInfo(ICQLINK *link, const char *nick, const char *first, const char *last,
-                           const char *email) /* V5 */
+			   const char *email) /* V5 */
 {
   icq_Packet *p = icq_UDPCreateStdPacket(link, UDP_CMD_NEW_USER_INFO);
   icq_PacketAppendString(p, nick);
