@@ -1,80 +1,25 @@
-/* -*- Mode: C; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
 /*
-$Id: util.c,v 1.1.1.1 2001/05/12 16:50:57 konst Exp $
-$Log: util.c,v $
-Revision 1.1.1.1  2001/05/12 16:50:57  konst
-Imported into the CVS repository
-
-Revision 1.32  2000/07/22 16:49:32  denis
-Trinidad and Tobago country was added.
-
-Revision 1.31  2000/07/21 16:51:20  denis
-All languages, possible in original icq were added.
-Occupation array fixed.
-
-Revision 1.30  2000/07/20 09:58:59  denis
-Occupation table corrected to comply with original ICQ.
-
-Revision 1.29  2000/07/04 07:25:29  pcadach
-icq_FmtLog() crashed when it receives NULL at link argument.
-
-Revision 1.28  2000/06/30 13:59:43  denis
-Slovak Republic country code fixed.
-
-Revision 1.27  2000/06/25 17:00:32  denis
-icq_MetaOccupation[], icq_MetaPastBackgrounds[],
-icq_MetaAffiliations[] and icq_MetaLanguages[] arrays were added along
-with icq_GetMetaOccupationName(), icq_GetMetaBackgroundName(),
-icq_GetMetaAffiliationName() and icq_GetMetaLanguageName() functions
-to access them.
-
-Revision 1.26  2000/05/21 17:42:51  denis
-Bulgaria country code was added. Thanks to
-"Napalm Death" <napalmbox@hotmail.com>
-
-Revision 1.25  2000/05/03 18:29:15  denis
-Callbacks have been moved to the ICQLINK structure.
-
-Revision 1.24  2000/04/10 16:36:04  denis
-Some more Win32 compatibility from Guillaume Rosanis <grs@mail.com>
-
-Revision 1.23  2000/04/05 14:37:02  denis
-Applied patch from "Guillaume R." <grs@mail.com> for basic Win32
-compatibility.
-
-Revision 1.22  2000/03/31 12:49:15  nofate
-remove static variable
-
-Revision 1.21  1999/11/11 15:10:33  guruz
-- Added Base for Webpager Messages. Please type "make fixme"
-- Removed Segfault when kicq is started the first time
-
-Revision 1.20  1999/10/07 18:01:40  denis
-Cleanups.
-
-Revision 1.19  1999/09/29 17:16:45  denis
-Cleanups.
-
-Revision 1.18  1999/07/18 20:24:27  bills
-removed old byte order and contact list functions
-
-Revision 1.17  1999/07/16 15:46:03  denis
-Cleaned up.
-
-Revision 1.16  1999/07/16 12:04:49  denis
-Status support changed.
-
-Revision 1.15  1999/07/12 15:13:46  cproch
-- added definition of ICQLINK to hold session-specific global variabled
-  applications which have more than one connection are now possible
-- changed nearly every function defintion to support ICQLINK parameter
-
-Revision 1.14  1999/04/17 19:20:35  bills
-removed *_link entries from icq_ContactItem, including cleanup/init code
-
-Revision 1.13  1999/04/14 15:06:51  denis
-Cleanups for "strict" compiling (-ansi -pedantic)
-
+*
+* $Id: util.c,v 1.3 2001/06/02 07:10:45 konst Exp $
+*
+* Copyright (C) 2000 Denis V. Dmitrienko <denis@null.net>
+* Copyright (C) 2000 Bill Soudan <soudan@kde.org>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
 */
 
 #include <stdlib.h>
@@ -479,7 +424,7 @@ void hex_dump(char *data, long size)
     if(i<size)
     {
       if(x==0)
-        printf("%04lx: ", i);
+	printf("%04lx: ", i);
 #ifdef _WIN32
       sprintf(d, "%08x", data[i]);
 #else
@@ -488,19 +433,19 @@ void hex_dump(char *data, long size)
       printf("%c%c ", d[6], d[7]);
       bfr[x]=data[i];
       if(bfr[x]<0x20)
-        bfr[x]='.';
+	bfr[x]='.';
       if(bfr[x]>0x7f)
-        bfr[x]='.';
+	bfr[x]='.';
     }
     else
     {
       if(x==0)
-        break;
+	break;
       else
       {
-        printf("   ");
-        bfr[x]=' ';
-        r=0;
+	printf("   ");
+	bfr[x]=' ';
+	r=0;
       }
     }
     x++;
@@ -510,7 +455,7 @@ void hex_dump(char *data, long size)
       printf("%s\n", bfr);
       x=0;
       if(!r)
-        break;
+	break;
     }
   }
 }
@@ -588,7 +533,7 @@ const char *icq_GetMetaOccupationName(unsigned short code)
     
   key.code=code;
   res=bsearch(&key, icq_MetaOccupation, sizeof(icq_MetaOccupation)/sizeof(icq_ArrayType),
-              sizeof(icq_ArrayType), array_code_compare);
+	      sizeof(icq_ArrayType), array_code_compare);
     
   return res?res->name:"Unknown";
 }
@@ -599,7 +544,7 @@ const char *icq_GetMetaBackgroundName(unsigned short code)
     
   key.code=code;
   res=bsearch(&key, icq_MetaPastBackgrounds, sizeof(icq_MetaPastBackgrounds)/sizeof(icq_ArrayType),
-              sizeof(icq_ArrayType), array_code_compare);
+	      sizeof(icq_ArrayType), array_code_compare);
     
   return res?res->name:"Unknown";
 }
@@ -610,7 +555,7 @@ const char *icq_GetMetaAffiliationName(unsigned short code)
     
   key.code=code;
   res=bsearch(&key, icq_MetaAffiliations, sizeof(icq_MetaAffiliations)/sizeof(icq_ArrayType),
-              sizeof(icq_ArrayType), array_code_compare);
+	      sizeof(icq_ArrayType), array_code_compare);
     
   return res?res->name:"Unknown";
 }
@@ -621,7 +566,7 @@ const char *icq_GetMetaLanguageName(unsigned short code)
     
   key.code=code;
   res=bsearch(&key, icq_MetaLanguages, sizeof(icq_MetaLanguages)/sizeof(icq_ArrayType),
-              sizeof(icq_ArrayType), array_code_compare);
+	      sizeof(icq_ArrayType), array_code_compare);
     
   return res?res->name:"Unknown";
 }
