@@ -1,7 +1,24 @@
 /*
 *
 * centericq core routines
-* $Id: centericq.cc,v 1.6 2001/05/11 19:27:04 konst Exp $
+* $Id: centericq.cc,v 1.9 2001/06/29 23:43:09 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
 *
 */
 
@@ -87,6 +104,7 @@ void centericq::exec() {
 	}
 
 	face.draw();
+	checkparallel();
 	mainloop();
     }
 
@@ -521,7 +539,7 @@ void centericq::checkmail() {
     bool prevempty, header;
     FILE *f;
 
-    if(fname)
+    if(conf.getmailcheck() && fname)
     if(!stat(fname, &st))
     if(st.st_size != fsize) {
 
@@ -565,3 +583,32 @@ void centericq::handlesignal(int signum) {
 	    break;
     }
 }
+
+void centericq::checkparallel() {
+    string pidfname = (string) getenv("HOME") + "/.centericq/pid", fname;
+    int pid = 0;
+    char exename[512];
+
+    ifstream f(pidfname.c_str());
+    if(f.is_open()) {
+	f >> pid;
+	f.close();
+    }
+
+    if(!(fname = readlink((string) "/proc/" + i2str(pid) + "/exe")).empty() && (pid != getpid())) {
+	if(justfname(fname) == "centericq") {
+	    face.log(_("! another running copy of centericq detected"));
+	    face.log(_("! this may cause problems. pid %lu"), pid);
+	}
+    } else {
+	pid = 0;
+    }
+
+    if(!pid) {
+	ofstream of(pidfname.c_str());
+	if(of.is_open()) {
+	    of << getpid() << endl;
+	    of.close();
+	}
+    }
+}
