@@ -1,3 +1,27 @@
+/*
+*
+* centericq configuration handling routines
+* $Id: icqconf.cc,v 1.5 2001/06/29 23:43:09 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
+
 #include <sys/types.h>
 #include <dirent.h>
 #include <fstream.h>
@@ -9,7 +33,8 @@
 #include "icqcontacts.h"
 
 icqconf::icqconf(): uin(0), rs(rscard), rc(rcdark), autoaway(0),
-autona(0), hideoffline(false), savepwd(true), antispam(false) {
+autona(0), hideoffline(false), savepwd(true), antispam(false),
+mailcheck(true) {
     setserver(ICQ_SERVER);
 }
 
@@ -69,6 +94,8 @@ void icqconf::loadmainconfig() {
 		autona = atol(buf.c_str());
 	    } else if(param == "antispam") {
 		antispam = true;
+	    } else if(param == "mailcheck") {
+		mailcheck = true;
 	    } else if(param == "server") {
 		setserver(buf);
 	    } else if(param == "quotemsgs") {
@@ -113,6 +140,7 @@ void icqconf::savemainconfig(unsigned int fuin = 0) {
 	if(hideoffline) f << "hideoffline" << endl;
 	if(getquote()) f << "quotemsgs" << endl;
 	if(getantispam()) f << "antispam" << endl;
+	if(getmailcheck()) f << "mailcheck" << endl;
 
 	f.close();
     }
@@ -287,9 +315,11 @@ void icqconf::loadactions() {
 	    of << "# Every line should look like: <action> <command>" << endl;
 	    of << "# Possible actions are: openurl" << endl << endl;
 
-	    of << "openurl\tif test ! -z \"`ps x | egrep '[0-9]:[0-9][0-9] netscape'`\";";
-	    of << " then netscape -remote 'openURL($url$, new-window)' -display 0:0;";
-	    of << " else /bin/sh -c \"netscape $url$ -display 0:0 >/dev/null 2>&1 &\"; fi" << endl;
+	    of << "openurl\t";
+	    of << "(if test ! -z \"`ps x | grep /netscape | grep -v grep`\"; ";
+	    of << "then netscape -remote 'openURL($url$, new-window)' -display 0:0; else ";
+	    of << "netscape \"$url$\" -display 0:0; fi) >/dev/null 2>&1 &" << endl;
+
 	    of.close();
 	}
     }
@@ -477,6 +507,14 @@ void icqconf::setantispam(bool fas) {
     antispam = fas;
 }
 
+bool icqconf::getmailcheck() {
+    return mailcheck;
+}
+
+void icqconf::setmailcheck(bool fmc) {
+    mailcheck = fmc;
+}
+
 void icqconf::openurl(const string url) {
     int npos;
     string torun = openurlcommand;
