@@ -12,10 +12,9 @@
 #include <list>
 #include <algorithm>
 
-#include "konst.list.h"
-#include "konst.string.h"
-#include "konst.fs.h"
-#include "konst.ui.func.h"
+#include "kkstrtext.h"
+#include "kkfsys.h"
+#include "conscommon.h"
 #include "icq.h"
 
 #define cp_status           1
@@ -65,7 +64,7 @@ class icqconf {
 	unsigned int uin, port, socksport;
 
 	int autoaway, autona;
-	bool hideoffline, quote, savepwd, antispam;
+	bool hideoffline, quote, savepwd, antispam, mailcheck;
 
 	string password, rnick, rfname, rlname, remail, server;
 	string sockshost, socksuser, sockspass, openurlcommand;
@@ -117,6 +116,9 @@ class icqconf {
 	bool getantispam();
 	void setantispam(bool fas);
 
+	bool getmailcheck();
+	void setmailcheck(bool fmc);
+
 	void setauto(int away, int na);
 	void getauto(int &away, int &na);
 
