@@ -1,3 +1,27 @@
+/*
+*
+* centericq single icq contact class
+* $Id: icqcontact.cc,v 1.5 2001/06/02 07:12:39 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
+
 #include "icqcontact.h"
 #include "icqcontacts.h"
 #include "icqconf.h"
@@ -701,3 +725,11 @@ void icqcontact::setpostponed(const string apostponed) {
 string icqcontact::getpostponed() {
     return postponed;
 }
+
+void icqcontact::setmsgdirect(bool flag) {
+    msgdirect = flag;
+}
+
+bool icqcontact::getmsgdirect() {
+    return msgdirect;
+}
