@@ -6,11 +6,9 @@
 #include <string>
 #include <dirent.h>
 
-#include "konst.list.h"
-#include "konst.string.h"
-#include "konst.fs.h"
-#include "konst.ui.func.h"
-#include "konst.ui.menu.h"
+#include "kkstrtext.h"
+#include "kkfsys.h"
+#include "cmenus.h"
 
 #include "icq.h"
 
@@ -21,7 +19,7 @@ class icqcontact {
 	unsigned int uin;
 	unsigned short seq2;
 	int status, nmsgs, fupdated, infotryn;
-	bool finlist, reqauth, webaware, pubip, nonicq, direct;
+	bool finlist, reqauth, webaware, pubip, nonicq, direct, msgdirect;
 	time_t lastread, lastseen;
 
 	string sound[SOUND_COUNT];
@@ -52,7 +50,6 @@ class icqcontact {
 	void setseq2(unsigned short fseq2);
 	void setnick(string fnick);
 	void setdispnick(string fnick);
-	void setdirect(bool flag);
 
 	void setinfo(string fname, string lname, string fprimemail,
 	    string fsecemail, string foldemail, string fcity,
@@ -126,7 +123,12 @@ class icqcontact {
 	void excludefromlist();
 	void includeintolist();
 	bool inlist();
+
+	void setdirect(bool flag);
 	bool getdirect();
+
+	void setmsgdirect(bool flag);
+	bool getmsgdirect();
 	
 	bool isnonicq();
 	bool isbirthday();
