@@ -1,3 +1,27 @@
+/*
+*
+* centericq user interface class, dialogs related part
+* $Id: icqdialogs.cc,v 1.5 2001/06/29 23:43:10 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
+
 #include "icqface.h"
 #include "icqconf.h"
 #include "icqhook.h"
@@ -591,6 +615,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
     bool socks = !conf.getsockshost().empty();
     bool hideoffl = conf.gethideoffline();
     bool antispam = conf.getantispam();
+    bool mailcheck = conf.getmailcheck();
 
     dialogbox db;
 
@@ -628,6 +653,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 	db.gettree()->addleaff(nopt, 0, (void *)  8, _(" Quote a message on reply : %s "), stryesno(quote));
 	db.gettree()->addleaff(nopt, 0, (void *) 13, _(" Remember ICQ password : %s "), stryesno(savepwd));
 	db.gettree()->addleaff(nopt, 0, (void *) 14, _(" Anti-spam: kill msgs from users not on the list : %s "), stryesno(antispam));
+	db.gettree()->addleaff(nopt, 0, (void *) 15, _(" Check the local mailbox : %s "), stryesno(mailcheck));
 
 	db.gettree()->addleaff(ncomm, 0, (void *) 7, _(" ICQ server address : %s "), serv.c_str());
 	db.gettree()->addleaff(ncomm, 0, (void *) 9, _(" Use SOCKS proxy : %s "), stryesno(socks));
@@ -687,6 +713,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 			break;
 		    case 13: savepwd = !savepwd; break;
 		    case 14: antispam = !antispam; break;
+		    case 15: mailcheck = !mailcheck; break;
 		}
 		break;
 	    case 1:
@@ -697,6 +724,7 @@ bool icqface::updateconf(regsound &s, regcolor &c) {
 		conf.setauto(aaway, ana);
 		conf.sethideoffline(hideoffl);
 		conf.setantispam(antispam);
+		conf.setmailcheck(mailcheck);
 		icq_Russian = rus ? 1 : 0;
 
 		if(socks) conf.setsockshost(prserv);
