@@ -1,3 +1,27 @@
+/*
+*
+* centericq user interface class
+* $Id: icqface.cc,v 1.9 2001/06/29 23:43:10 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
+
 #include "icqface.h"
 #include "icqconf.h"
 #include "icqhook.h"
@@ -8,7 +32,6 @@
 #include "icqmlist.h"
 #include "icqoffline.h"
 
-#include "konst.socket.h"
 #include <regex.h>
 
 const char *stryesno(bool i) {
@@ -68,6 +91,7 @@ string getbdate(unsigned char bday, unsigned char bmonth, unsigned char byear) {
 
 icqface::icqface(): mainscreenblock(false), inited(false), onlinefolder(false) {
     kinterface();
+    raw();
     workareas.freeitem = &freeworkareabuf;
 
 #ifdef DEBUG
@@ -154,8 +178,7 @@ int icqface::contextmenu(icqcontact *c) {
     int ret = 0, i;
     static int elem = 0;
 
-    verticalmenu m(WORKAREA_X1+1, WORKAREA_Y1+1,
-	WORKAREA_X1+27, WORKAREA_Y1+2, conf.getcolor(cp_main_text),
+    verticalmenu m(conf.getcolor(cp_main_text),
 	conf.getcolor(cp_main_selected));
 
     m.setwindow(textwindow(WORKAREA_X1, WORKAREA_Y1, WORKAREA_X1+27,
@@ -875,39 +898,39 @@ string icqface::textstatus(unsigned long st) {
     if(!(st & 0x01FF)) return _("Online"); else return _("Unknown");
 }
 
+#define INPUT_POS       LINES-2
+
 string icqface::inputstr(string q, string defl = "", char passwdchar = 0) {
-    int ln = LINES-2;
-    chtype **sbuf = savelines(0, ln, COLS, ln);
+    screenarea sa(0, INPUT_POS, COLS, INPUT_POS);
     string ret;
     char *p;
 
     attrset(conf.getcolor(cp_status));
-    mvhline(ln, 0, ' ', COLS);
-    kwriteatf(0, ln, conf.getcolor(cp_status), "%s", q.c_str());
+    mvhline(INPUT_POS, 0, ' ', COLS);
+    kwriteatf(0, INPUT_POS, conf.getcolor(cp_status), "%s", q.c_str());
     il->setpasswordchar(passwdchar);
     il->fm = 0;
 
-    ret = (p = il->open(q.size(), ln, defl.c_str(), COLS-q.size()-1, 2048));
+    ret = (p = il->open(q.size(), INPUT_POS, defl.c_str(), COLS-q.size()-1, 2048));
     delete p;
 
-    restorelines(sbuf, 0, ln, COLS, ln);
+    sa.restore();
     return ret;
 }
 
 string icqface::inputfile(string q, string defl = "") {
-    int ln = LINES-2;
-    chtype **sbuf = savelines(0, ln, COLS, ln);
+    screenarea sa(0, INPUT_POS, COLS, INPUT_POS);
     string ret;
     char *p, *r;
 
-    mvhline(ln, 0, ' ', COLS);
-    kwriteatf(0, ln, conf.getcolor(cp_status), "%s", q.c_str());
-    kwriteatf(COLS-8, ln, conf.getcolor(cp_status), "[Ctrl-T]");
+    mvhline(INPUT_POS, 0, ' ', COLS);
+    kwriteatf(0, INPUT_POS, conf.getcolor(cp_status), "%s", q.c_str());
+    kwriteatf(COLS-8, INPUT_POS, conf.getcolor(cp_status), "[Ctrl-T]");
 
     il->fm = fm;
     il->fm->w->set_title(conf.getcolor(cp_dialog_highlight), _(" enter to select a file, esc to cancel "));
     fm->onlydirs = fm->chroot = false;
-    ret = (p = il->open(q.size(), ln, defl.c_str(), COLS-q.size()-10, 2048));
+    ret = (p = il->open(q.size(), INPUT_POS, defl.c_str(), COLS-q.size()-10, 2048));
 
     if(r = strrchr(p, '/')) {
 	*r = 0;
@@ -916,7 +939,7 @@ string icqface::inputfile(string q, string defl = "") {
 
     delete p;
 
-    restorelines(sbuf, 0, ln, COLS, ln);
+    sa.restore();
     return ret;
 }
 
@@ -934,8 +957,8 @@ void catqstr(string &q, int option, int defl) {
 }
 
 int icqface::ask(string q, int options, int deflt = -1) {
-    int ln = LINES-1, ret;
-    chtype **sbuf = savelines(0, ln, COLS, ln);
+    int ret;
+    screenarea sa(0, INPUT_POS, COLS, INPUT_POS);
 
     q += " (";
     if(options & ASK_YES) catqstr(q, ASK_YES, deflt);
@@ -944,8 +967,8 @@ int icqface::ask(string q, int options, int deflt = -1) {
     q += ") ";
 
     attrset(conf.getcolor(cp_status));
-    mvhline(ln, 0, ' ', COLS);
-    kwriteatf(0, ln, conf.getcolor(cp_status), "%s", q.c_str());
+    mvhline(INPUT_POS, 0, ' ', COLS);
+    kwriteatf(0, INPUT_POS, conf.getcolor(cp_status), "%s", q.c_str());
 
     for(ret = -1; ret == -1; ) {
 	switch(getkey()) {
@@ -967,7 +990,7 @@ int icqface::ask(string q, int options, int deflt = -1) {
 	}
     }
 
-    restorelines(sbuf, 0, ln, COLS, ln);
+    sa.restore();
     return ret;
 }
 
@@ -1535,7 +1558,12 @@ void icqface::acceptfile(unsigned int uin, unsigned long seq, string fname) {
 
 	if(sess = icq_AcceptFileRequest(&icql, uin, seq)) {
 	    log(_("+ file %s from %s, %lu started"), justfname(fname).c_str(), c->getdispnick().c_str(), uin);
-	    ihook.addfile(uin, seq, fname, HIST_MSG_IN);
+
+	    if(!access((filesavedir + "/" + justfname(fname)).c_str(), F_OK)) {
+		log(_("+ already exists, skipping"));
+	    } else {
+		ihook.addfile(uin, seq, fname, HIST_MSG_IN);
+	    }
 	}
     }
 }
