@@ -1,3 +1,27 @@
+/*
+*
+* centericq messages sending/auto-postponing class
+* $Id: icqoffline.cc,v 1.6 2001/06/07 08:47:00 konst Exp $
+*
+* Copyright (C) 2001 by Konstantin Klyagin <konst@konst.org.ua>
+*
+* This program is free software; you can redistribute it and/or modify
+* it under the terms of the GNU General Public License as published by
+* the Free Software Foundation; either version 2 of the License, or (at
+* your option) any later version.
+*
+* This program is distributed in the hope that it will be useful, but
+* WITHOUT ANY WARRANTY; without even the implied warranty of
+* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+* General Public License for more details.
+*
+* You should have received a copy of the GNU General Public License
+* along with this program; if not, write to the Free Software
+* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+* USA
+*
+*/
+
 #include "icqoffline.h"
 #include "icqhist.h"
 #include "icqcontact.h"
@@ -25,7 +49,7 @@ void icqoffline::sendmsg(unsigned int uin, string text) {
     vector<string> lst;
 
     if(f) {
-	if(!c->getdirect()) {
+	if(!c->getmsgdirect()) {
 	    splitlongtext(text, lst, MAX_UDPMSG_SIZE, "\r\n[continued]");
 	}
 
@@ -36,7 +60,7 @@ void icqoffline::sendmsg(unsigned int uin, string text) {
 	    }
 
 	    seq = icq_SendMessage(&icql, uin, text.c_str(),
-		c->getdirect() ? ICQ_SEND_BESTWAY : ICQ_SEND_THRUSERVER);
+		c->getmsgdirect() ? ICQ_SEND_BESTWAY : ICQ_SEND_THRUSERVER);
 
 	    fprintf(f, "\f\nMSG\n");
 	    fprintf(f, "%lu\n%lu\n", seq, time(0));
@@ -81,12 +105,12 @@ unsigned long sseq) {
     if(c) {
 	lst.clear();
 	send = save = true;
-	way = c->getdirect() ? ICQ_SEND_BESTWAY : ICQ_SEND_THRUSERVER;
+	way = c->getmsgdirect() ? ICQ_SEND_BESTWAY : ICQ_SEND_THRUSERVER;
 
 	switch(act) {
 	    case osresend:
 		if(send = (sseq == seq)) {
-		    c->setdirect(false);
+		    c->setmsgdirect(false);
 		    if(text.size() < MAX_UDPMSG_SIZE) {
 			way = ICQ_SEND_THRUSERVER;
 		    } else {
@@ -97,7 +121,7 @@ unsigned long sseq) {
 		break;
 	    case osexpired:
 		if(send = (time(0)-tm > PERIOD_RESEND)) {
-		    c->setdirect(false);
+		    c->setmsgdirect(false);
 		    if(text.size() < MAX_UDPMSG_SIZE) {
 			way = ICQ_SEND_THRUSERVER;
 		    } else {
@@ -167,7 +191,7 @@ void icqoffline::scan(unsigned long sseq, scanaction act) {
     FILE *f, *of;
     char buf[512];
     string url, text, ofname;
-    bool msg, fin = false;
+    bool msg;
 
     totalunsent = 0;
 
@@ -179,12 +203,12 @@ void icqoffline::scan(unsigned long sseq, scanaction act) {
 	    ofname = (string) getenv("HOME") + "/.centericq/tmp." + i2str(getpid());
 	    of = fopen(ofname.c_str(), "w");
 
-	    while(!feof(f) && !fin) {
+	    while(!feof(f)) {
 		freads(f, buf, 512);
 
 		if((string) buf == "\f") {
 		    l = 0;
-		    fin = sendevent(uin, msg, url, text, of, seq, t, act, sseq);
+		    sendevent(uin, msg, url, text, of, seq, t, act, sseq);
 		    text = url = "";
 		} else {
 		    switch(l) {
